==> kubernetes-model-core-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/CreateOptionsFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class CreateOptionsFluent<A extends CreateOptionsFluent<A>> extends BaseFluent<A>{
  public CreateOptionsFluent() {
  }
  
  public CreateOptionsFluent(CreateOptions instance) {
    this.copyInstance(instance);
  }
  private String apiVersion;
  private List<String> dryRun = new ArrayList<String>();
  private String fieldManager;
  private String fieldValidation;
  private String kind;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(CreateOptions instance) {
    instance = (instance != null ? instance : new CreateOptions());
  
    if (instance != null) {
        this.withApiVersion(instance.getApiVersion());
        this.withDryRun(instance.getDryRun());
        this.withFieldManager(instance.getFieldManager());
        this.withFieldValidation(instance.getFieldValidation());
        this.withKind(instance.getKind());
        this.withApiVersion(instance.getApiVersion());
        this.withDryRun(instance.getDryRun());
        this.withFieldManager(instance.getFieldManager());
        this.withFieldValidation(instance.getFieldValidation());
        this.withKind(instance.getKind());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getApiVersion() {
    return this.apiVersion;
  }
  
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  
  public boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  public A addToDryRun(int index,String item) {
    if (this.dryRun == null) {this.dryRun = new ArrayList<String>();}
    this.dryRun.add(index, item);
    return (A)this;
  }
  
  public A setToDryRun(int index,String item) {
    if (this.dryRun == null) {this.dryRun = new ArrayList<String>();}
    this.dryRun.set(index, item); return (A)this;
  }
  
  public A addToDryRun(java.lang.String... items) {
    if (this.dryRun == null) {this.dryRun = new ArrayList<String>();}
    for (String item : items) {this.dryRun.add(item);} return (A)this;
  }
  
  public A addAllToDryRun(Collection<String> items) {
    if (this.dryRun == null) {this.dryRun = new ArrayList<String>();}
    for (String item : items) {this.dryRun.add(item);} return (A)this;
  }
  
  public A removeFromDryRun(java.lang.String... items) {
    if (this.dryRun == null) return (A)this;
    for (String item : items) { this.dryRun.remove(item);} return (A)this;
  }
  
  public A removeAllFromDryRun(Collection<String> items) {
    if (this.dryRun == null) return (A)this;
    for (String item : items) { this.dryRun.remove(item);} return (A)this;
  }
  
  public List<String> getDryRun() {
    return this.dryRun;
  }
  
  public String getDryRun(int index) {
    return this.dryRun.get(index);
  }
  
  public String getFirstDryRun() {
    return this.dryRun.get(0);
  }
  
  public String getLastDryRun() {
    return this.dryRun.get(dryRun.size() - 1);
  }
  
  public String getMatchingDryRun(Predicate<String> predicate) {
    for (String item: dryRun) { if(predicate.test(item)){ return item;} } return null;
  }
  
  public boolean hasMatchingDryRun(Predicate<String> predicate) {
    for (String item: dryRun) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withDryRun(List<String> dryRun) {
    if (dryRun != null) {this.dryRun = new ArrayList(); for (String item : dryRun){this.addToDryRun(item);}} else { this.dryRun = null;} return (A) this;
  }
  
  public A withDryRun(java.lang.String... dryRun) {
    if (this.dryRun != null) {this.dryRun.clear(); _visitables.remove("dryRun"); }
    if (dryRun != null) {for (String item :dryRun){ this.addToDryRun(item);}} return (A) this;
  }
  
  public boolean hasDryRun() {
    return dryRun != null && !dryRun.isEmpty();
  }
  
  public String getFieldManager() {
    return this.fieldManager;
  }
  
  public A withFieldManager(String fieldManager) {
    this.fieldManager=fieldManager; return (A) this;
  }
  
  public boolean hasFieldManager() {
    return this.fieldManager != null;
  }
  
  public String getFieldValidation() {
    return this.fieldValidation;
  }
  
  public A withFieldValidation(String fieldValidation) {
    this.fieldValidation=fieldValidation; return (A) this;
  }
  
  public boolean hasFieldValidation() {
    return this.fieldValidation != null;
  }
  
  public String getKind() {
    return this.kind;
  }
  
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  
  public boolean hasKind() {
    return this.kind != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CreateOptionsFluent that = (CreateOptionsFluent) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;
  
    if (!java.util.Objects.equals(dryRun, that.dryRun)) return false;
  
    if (!java.util.Objects.equals(fieldManager, that.fieldManager)) return false;
  
    if (!java.util.Objects.equals(fieldValidation, that.fieldValidation)) return false;
  
    if (!java.util.Objects.equals(kind, that.kind)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  dryRun,  fieldManager,  fieldValidation,  kind,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (dryRun != null && !dryRun.isEmpty()) { sb.append("dryRun:"); sb.append(dryRun + ","); }
    if (fieldManager != null) { sb.append("fieldManager:"); sb.append(fieldManager + ","); }
    if (fieldValidation != null) { sb.append("fieldValidation:"); sb.append(fieldValidation + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> kubernetes-model-core-6.9.1-sources.jar: io/fabric8/kubernetes/api/model/CreateOptionsFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class CreateOptionsFluent<A extends CreateOptionsFluent<A>> extends BaseFluent<A>{
  public CreateOptionsFluent() {
  }
  
  public CreateOptionsFluent(CreateOptions instance) {
    this.copyInstance(instance);
  }
  private String apiVersion;
  private List<String> dryRun = new ArrayList<String>();
  private String fieldManager;
  private String fieldValidation;
  private String kind;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(CreateOptions instance) {
    instance = (instance != null ? instance : new CreateOptions());
    if (instance != null) {
          this.withApiVersion(instance.getApiVersion());
          this.withDryRun(instance.getDryRun());
          this.withFieldManager(instance.getFieldManager());
          this.withFieldValidation(instance.getFieldValidation());
          this.withKind(instance.getKind());
          this.withApiVersion(instance.getApiVersion());
          this.withDryRun(instance.getDryRun());
          this.withFieldManager(instance.getFieldManager());
          this.withFieldValidation(instance.getFieldValidation());
          this.withKind(instance.getKind());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getApiVersion() {
    return this.apiVersion;
  }
  
  public A withApiVersion(String apiVersion) {
    this.apiVersion = apiVersion;
    return (A) this;
  }
  
  public boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  public A addToDryRun(int index,String item) {
    if (this.dryRun == null) {this.dryRun = new ArrayList<String>();}
    this.dryRun.add(index, item);
    return (A)this;
  }
  
  public A setToDryRun(int index,String item) {
    if (this.dryRun == null) {this.dryRun = new ArrayList<String>();}
    this.dryRun.set(index, item); return (A)this;
  }
  
  public A addToDryRun(java.lang.String... items) {
    if (this.dryRun == null) {this.dryRun = new ArrayList<String>();}
    for (String item : items) {this.dryRun.add(item);} return (A)this;
  }
  
  public A addAllToDryRun(Collection<String> items) {
    if (this.dryRun == null) {this.dryRun = new ArrayList<String>();}
    for (String item : items) {this.dryRun.add(item);} return (A)this;
  }
  
  public A removeFromDryRun(java.lang.String... items) {
    if (this.dryRun == null) return (A)this;
    for (String item : items) { this.dryRun.remove(item);} return (A)this;
  }
  
  public A removeAllFromDryRun(Collection<String> items) {
    if (this.dryRun == null) return (A)this;
    for (String item : items) { this.dryRun.remove(item);} return (A)this;
  }
  
  public List<String> getDryRun() {
    return this.dryRun;
  }
  
  public String getDryRun(int index) {
    return this.dryRun.get(index);
  }
  
  public String getFirstDryRun() {
    return this.dryRun.get(0);
  }
  
  public String getLastDryRun() {
    return this.dryRun.get(dryRun.size() - 1);
  }
  
  public String getMatchingDryRun(Predicate<String> predicate) {
      for (String item : dryRun) {
        if (predicate.test(item)) {
          return item;
        }
      }
      return null;
  }
  
  public boolean hasMatchingDryRun(Predicate<String> predicate) {
      for (String item : dryRun) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withDryRun(List<String> dryRun) {
    if (dryRun != null) {
        this.dryRun = new ArrayList();
        for (String item : dryRun) {
          this.addToDryRun(item);
        }
    } else {
      this.dryRun = null;
    }
    return (A) this;
  }
  
  public A withDryRun(java.lang.String... dryRun) {
    if (this.dryRun != null) {this.dryRun.clear(); _visitables.remove("dryRun"); }
    if (dryRun != null) {for (String item :dryRun){ this.addToDryRun(item);}} return (A) this;
  }
  
  public boolean hasDryRun() {
    return this.dryRun != null && !this.dryRun.isEmpty();
  }
  
  public String getFieldManager() {
    return this.fieldManager;
  }
  
  public A withFieldManager(String fieldManager) {
    this.fieldManager = fieldManager;
    return (A) this;
  }
  
  public boolean hasFieldManager() {
    return this.fieldManager != null;
  }
  
  public String getFieldValidation() {
    return this.fieldValidation;
  }
  
  public A withFieldValidation(String fieldValidation) {
    this.fieldValidation = fieldValidation;
    return (A) this;
  }
  
  public boolean hasFieldValidation() {
    return this.fieldValidation != null;
  }
  
  public String getKind() {
    return this.kind;
  }
  
  public A withKind(String kind) {
    this.kind = kind;
    return (A) this;
  }
  
  public boolean hasKind() {
    return this.kind != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CreateOptionsFluent that = (CreateOptionsFluent) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;
    if (!java.util.Objects.equals(dryRun, that.dryRun)) return false;
    if (!java.util.Objects.equals(fieldManager, that.fieldManager)) return false;
    if (!java.util.Objects.equals(fieldValidation, that.fieldValidation)) return false;
    if (!java.util.Objects.equals(kind, that.kind)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  dryRun,  fieldManager,  fieldValidation,  kind,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (dryRun != null && !dryRun.isEmpty()) { sb.append("dryRun:"); sb.append(dryRun + ","); }
    if (fieldManager != null) { sb.append("fieldManager:"); sb.append(fieldManager + ","); }
    if (fieldValidation != null) { sb.append("fieldValidation:"); sb.append(fieldValidation + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
